//=============================================================================
// RPGツクールMZ - LL_CustomFadeMV.js v1.0.1
//-----------------------------------------------------------------------------
// ルルの教会 (Lulu's Church)
// https://nine-yusha.com/
//
// URL below for license details.
// https://nine-yusha.com/plugin/
//=============================================================================

/*:
 * @target MV
 * @plugindesc 切り替え時間を指定できるフェードイン・フェードアウト機能を実装します。
 * @author ルルの教会
 * @url https://nine-yusha.com/plugin-customfade/
 *
 * @help LL_CustomFadeMV.js
 *
 * 切り替え時間を指定できるフェードアウト・フェードイン機能を実装します。
 * プラグインコマンドを使用して、フェードアウト・フェードインを実行します。
 *
 * プラグインコマンド:
 *   LL_CustomFadeMV fadeout 60 true   # フェードアウト (60フレーム)
 *   LL_CustomFadeMV fadeout 90 false  # フェードアウト (90フレーム、ウェイト無)
 *   LL_CustomFadeMV fadein 60 true    # フェードイン (60フレーム)
 *   LL_CustomFadeMV fadein 90 false   # フェードイン (90フレーム、ウェイト無)
 *
 * 利用規約:
 *   ・著作権表記は必要ございません。
 *   ・利用するにあたり報告の必要は特にございません。
 *   ・商用・非商用問いません。
 *   ・R18作品にも使用制限はありません。
 *   ・ゲームに合わせて自由に改変していただいて問題ございません。
 *   ・プラグイン素材としての再配布（改変後含む）は禁止させていただきます。
 *
 * 作者: ルルの教会
 * 作成日: 2020/11/26
 *
 * @command fadeout
 * @text フェードアウト
 * @desc 画面を徐々に暗くし、そのまま真っ暗にします。
 *
 * @arg time
 * @text 時間
 * @desc フェードアウトする時間をフレーム単位(1/60秒)で指定します。
 * @default 60
 * @type number
 *
 * @arg waiting
 * @text 完了までウェイト
 * @desc 効果が終了するまで待ちます。
 * @default true
 * @type boolean
 *
 * @command fadein
 * @text フェードイン
 * @desc フェードアウトした画面を徐々に明るくし、元に戻します。
 *
 * @arg time
 * @text 時間
 * @desc フェードインする時間をフレーム単位(1/60秒)で指定します。
 * @default 60
 * @type number
 *
 * @arg waiting
 * @text 完了までウェイト
 * @desc 効果が終了するまで待ちます。
 * @default true
 * @type boolean
 */

(function() {
    "use strict";
    const pluginName = "LL_CustomFadeMV";

    //-----------------------------------------------------------------------------
	// PluginCommand (for MV)
    //

    var _Game_Interpreter_pluginCommand = Game_Interpreter.prototype.pluginCommand;
    Game_Interpreter.prototype.pluginCommand = function(command, args) {
        _Game_Interpreter_pluginCommand.call(this, command, args);
        if (command === pluginName) {
            switch (args[0]) {
				case 'fadeout':
                    var time = Number(args[1]);
                    var waiting = eval(args[2] || "true");
                    if (!$gameMessage.isBusy()) {
                        $gameScreen.startFadeOut(time);
                        if (waiting) {
                            this.wait(time);
                        }
                    }
					break;
				case 'fadein':
					var time = Number(args[1]);
                    var waiting = eval(args[2] || "true");
                    if (!$gameMessage.isBusy()) {
                        $gameScreen.startFadeIn(time);
                        if (waiting) {
                            this.wait(time);
                        }
                    }
					break;
            }
        }
	};
})();
